@@ -261,6 +261,8 @@ class Experiment(BaseModel):
         title="Filtering conditions", description="""List of filtering conditions to apply on exposure and goals."""
     )
 
+    outlier_detection_algorithm: Optional[str] = Field(title="Outlier detection algorithm")
+
     @validator("id")
     def id_must_be_not_empty(cls, value):
         if not value:
@@ -337,6 +339,7 @@ class Experiment(BaseModel):
             variants=self.variants,
             statsd=statsd,
             filters=[f.to_filter() for f in self.filters] if self.filters else [],
+            outlier_detection_algorithm=self.outlier_detection_algorithm,
         )
 
     class Config:
