@@ -1,6 +1,6 @@
 from .experiment import Experiment, Evaluation, Filter, FilterScope
 from .metric import Metric, SimpleMetric
-from .check import Check, SrmCheck, SimpleSrmCheck
+from .check import Check, SrmCheck, SimpleSrmCheck, SumRatioCheck
 from .parser import Parser, EpGoal
 from .dao import Dao, DaoFactory
 from .statistics import Statistics
